@@ -1,9 +1,12 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::OptionalFeature; # git description: v0.020-10-ge385fd3
+package Dist::Zilla::Plugin::OptionalFeature; # git description: v0.021-29-g271917d
 # ABSTRACT: Specify prerequisites for optional features in your distribution
-# vim: set ts=8 sw=4 tw=78 et :
-our $VERSION = '0.021';
+# KEYWORDS: plugin metadata prerequisites optional recommended prompt install
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
+
+our $VERSION = '0.022';
+
 use Moose;
 with
     'Dist::Zilla::Role::BeforeBuild',
@@ -30,6 +33,12 @@ has always_recommend => (
     default => 0,
 );
 
+has always_suggest => (
+    is => 'ro', isa => Bool,
+    lazy => 1,
+    default => sub { shift->always_recommend ? 0 : 1 },
+);
+
 has require_develop => (
     is => 'ro', isa => Bool,
     default => 1,
@@ -47,7 +56,7 @@ has default => (
     # NO DEFAULT
 );
 
-has load_prereqs => (
+has check_prereqs => (
     is => 'ro', isa => Bool,
     default => 1,
 );
@@ -72,7 +81,7 @@ has _prereqs => (
     handles => { _prereq_modules => 'keys', _prereq_version => 'get' },
 );
 
-sub mvp_aliases { +{ -relationship => '-type' } }
+sub mvp_aliases { +{ -relationship => '-type', -load_prereqs => '-check_prereqs' } }
 
 around BUILDARGS => sub
 {
@@ -89,7 +98,7 @@ around BUILDARGS => sub
 
     my %opts = (
         map { exists $args->{$_} ? ( substr($_, 1) => delete($args->{$_}) ) : () }
-        qw(-name -description -always_recommend -require_develop -prompt -default -load_prereqs -phase -type));
+        qw(-name -description -always_recommend -always_suggest -require_develop -prompt -default -check_prereqs -phase -type));
     $opts{type} //= delete $args->{'-relationship'} if defined $args->{'-relationship'};
 
     my @other_options = grep { /^-/ } keys %$args;
@@ -135,9 +144,9 @@ has _dynamicprereqs_prompt => (
         my $self = shift;
 
         my $phase = $self->_prereq_phase;
-        my $mm_key = $phase eq 'runtime' ? 'PREREQ_PM'
-            : $phase eq 'test' ? 'TEST_REQUIRES'
-            : $phase eq 'build' ? 'BUILD_REQUIRES'
+        my $function = $phase eq 'runtime' ? 'requires'
+            : $phase eq 'test' ? 'test_requires'
+            : $phase eq 'build' ? 'build_requires'
             : $self->log_fatal("illegal phase $phase");
         $self->log_fatal('prompts are only used for the \'requires\' type')
             if $self->_prereq_type ne 'requires';
@@ -147,26 +156,26 @@ has _dynamicprereqs_prompt => (
         my $prompt = "prompt('install $description? "
                 . ($self->default ? "[Y/n]', 'Y'" : "[y/N]', 'N'" )
                 . ') =~ /^y/i';
-        my @assignments = map {
-            qq!\$WriteMakefileArgs{$mm_key}{'$_'} = \$FallbackPrereqs{'$_'} = '${ \$self->_prereq_version($_) }'!
+        my @directives = map {
+            my $version = $self->_prereq_version($_);
+            $function . "('$_'" . ($version ? ", '$version'" : '') . ')'
         } sort $self->_prereq_modules;
-        my $require_clause = !$self->load_prereqs ? ''
-            : ('eval "' . join('', map {
-                my $version = $self->_prereq_version($_);
-                "require $_; " . ($version ? "$_->VERSION('$version'); " : '')
-            } sort $self->_prereq_modules) . '1"' . "\n    || ");
 
-        # TODO: in the future, [DynamicPrereqs] will have more sophisticated
-        # options, so we would just need to pass the prompt text, default
-        # answer, and list of prereqs and phases.
+        my $require_clause = !$self->check_prereqs ? ''
+            : (join(' && ', map {
+                my $version = $self->_prereq_version($_);
+                "has_module('$_'" . ($version ? ", '$version'" : '') . ')'
+            } sort $self->_prereq_modules
+        ) . "\n    || ");
+
         [
-            @assignments > 1
+            @directives > 1
                 ? (
                     'if (' . $require_clause . $prompt . ') {',   # to mollify vim
-                    (map { '  ' . $_ . ';' } @assignments),
+                    (map { '  ' . $_ . ';' } @directives),
                     '}',
                   )
-                : ( @assignments, '  if ' . $require_clause . $prompt . ';' )
+                : ( @directives , '  if ' . $require_clause . $prompt . ';' )
         ];
     },
 );
@@ -192,6 +201,7 @@ sub before_build
         my $plugin = use_module('Dist::Zilla::Plugin::DynamicPrereqs')->new(
             zilla => $self->zilla,
             plugin_name => 'via OptionalFeature',
+            # if we require 0.018, we can s/raw/body/.
             raw => [
                 join("\n",
                     map {
@@ -211,15 +221,16 @@ around dump_config => sub
     my $config = $self->$orig;
 
     $config->{+__PACKAGE__} = {
-        (map { $_ => $self->$_ }
-            qw(name description always_recommend require_develop prompt)),
-        $self->prompt ? ( load_prereqs => $self->load_prereqs ) : (),
+        (map { $_ => $self->$_ } qw(name description )),
+        (map { $_ => ($self->$_ ? 1 : 0) } qw(always_recommend always_suggest require_develop prompt)),
+        $self->prompt ? ( check_prereqs => $self->check_prereqs ) : (),
         # FIXME: YAML::Tiny does not handle leading - properly yet
         # (map { defined $self->$_ ? ( '-' . $_ => $self->$_ ) : () }
         (map { defined $self->$_ ? ( $_ => $self->$_ ) : () } qw(default)),
         phase => $self->_prereq_phase,
         type => $self->_prereq_type,
         prereqs => $self->_prereqs,
+        blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
     };
 
     return $config;
@@ -231,20 +242,24 @@ sub register_prereqs
 
     $self->zilla->register_prereqs(
         {
-            type  => 'requires',
             phase => 'develop',
+            type  => 'requires',
         },
         %{ $self->_prereqs },
     ) if $self->require_develop;
 
-    return if not $self->always_recommend;
-    $self->zilla->register_prereqs(
-        {
-            type  => 'recommends',
-            phase => $self->_prereq_phase,
-        },
-        %{ $self->_prereqs },
-    );
+    foreach my $phase (qw(recommend suggest))
+    {
+        $self->zilla->register_prereqs(
+            {
+                phase => $self->_prereq_phase,
+                type  => $phase . 's',
+            },
+            %{ $self->_prereqs },
+        ) if $self->${\"always_$phase"};
+    }
+
+    return;
 }
 
 sub metadata
@@ -286,7 +301,7 @@ Dist::Zilla::Plugin::OptionalFeature - Specify prerequisites for optional featur
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
@@ -378,21 +393,17 @@ C<dzil build>.
 
 =head1 CONFIGURATION OPTIONS
 
-This is mostly a restating of the information above.
-
-=over 4
-
-=item * C<-name>
+=head2 C<-name>
 
 The name of the optional feature, to be presented to the user. Can also be
 extracted from the plugin name.
 
-=item * C<-description>
+=head2 C<-description>
 
 The description of the optional feature, to be presented to the user.
 Defaults to the feature name, if not provided.
 
-=item * C<-always_recommend>
+=head2 C<-always_recommend>
 
 If set with a true value, the prerequisites are added to the distribution's
 metadata as recommended prerequisites (e.g. L<cpanminus> will install
@@ -401,7 +412,18 @@ non-interactively).
 
 Defaults to C<false>, but I recommend you turn this on.
 
-=item * C<-require_develop>
+=head2 C<-always_suggest>
+
+(Available since version 0.022)
+
+If set with a true value, the prerequisites are added to the distribution's
+metadata as suggested prerequisites.
+
+Defaults to the inverse of C<-always_recommend>.
+
+=head2 C<-require_develop>
+
+(Available since version 0.011)
 
 If set with a true value, the prerequisites are added to the distribution's
 metadata as develop requires prerequisites (e.g. L<cpanminus> will install
@@ -410,7 +432,7 @@ non-interactively).
 
 Defaults to C<true>.
 
-=item * C<-prompt>
+=head2 C<-prompt>
 
 (Available since version 0.017)
 
@@ -420,9 +442,9 @@ prompts.
 Default is C<true> if C<-relationship> is C<requires>.
 C<false> otherwise.
 
-=item * C<-load_prereqs>
+=head2 C<-check_prereqs>
 
-(Available since version 0.021)
+(Available since version 0.021 as -load_prereqs, 0.022 as its present name)
 
 If set, and C<-prompt> is also set, the prerequisites to be added by the feature
 are checked for in the Perl installation; if the requirements are already met,
@@ -430,7 +452,7 @@ then the feature is automatically added.
 
 Default is C<true>.
 
-=item * C<-default>
+=head2 C<-default>
 
 (Available since version 0.006)
 
@@ -443,30 +465,20 @@ Note that at the time of this feature's creation (September 2013), there is no
 compliant CPAN client yet, as it invents a new C<x_default> field in metadata
 under C<optional_feature> (thanks, miyagawa!)
 
-=item * C<-phase>
+=head2 C<-phase>
 
 The phase of the prequisite(s). Should be one of: build, test, runtime,
 or develop.
 
 Default: C<runtime>
 
-=item * C<-relationship> (or C<-type>)
+=head2 C<-relationship> (or C<-type>)
 
 The relationship of the prequisite(s). Should be one of: requires, recommends,
 suggests, or conflicts.
 
 Default: C<requires>
 
-=back
-
-=head1 SUPPORT
-
-=for stopwords irc
-
-Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-OptionalFeature>
-(or L<bug-Dist-Zilla-Plugin-OptionalFeature@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-OptionalFeature@rt.cpan.org>).
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 SEE ALSO
 
 =over 4
@@ -481,21 +493,34 @@ L<Module::Install::API/features, feature (Module::Install::Metadata)>
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-OptionalFeature>
+(or L<bug-Dist-Zilla-Plugin-OptionalFeature@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-OptionalFeature@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Karen Etheridge <ether@cpan.org>
 
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by Karen Etheridge.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 CONTRIBUTOR
 
 =for stopwords Kent Fredric
 
 Kent Fredric <kentnl@cpan.org>
 
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2013 by Karen Etheridge.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
